@@ -3,8 +3,7 @@
 """Non-graphical part of the Table step in SEAMM"""
 
 import logging
-import os.path
-from pathlib import PurePath
+from pathlib import Path, PurePath
 
 import numpy as np
 import pandas
@@ -35,6 +34,7 @@ class Table(seamm.Node):
 
         # This needs to be after initializing subclasses...
         self.parameters = table_step.TableParameters()
+        self.calls = 0
 
     @property
     def version(self):
@@ -87,17 +87,23 @@ class Table(seamm.Node):
             filename = P["filename"]
             file_type = P["file type"]
             if file_type == "from extension":
-                file_type = PurePath(filename).suffix
-                if file_type not in self.parameters["file type"].enumeration:
-                    types = "', '".join(self.parameters["file type"].enumeration)
-                    raise RuntimeError(
-                        f"Cannot handle files of type '{file_type}' when reading "
-                        f"table '{tablename}'.\nKnown types: '{types}'"
+                if isinstance(filename, str) and self.is_expr(filename):
+                    lines.append(
+                        f"        File: from variable '{filename}' with type from the "
+                        "extension"
+                    )
+                else:
+                    file_type = PurePath(filename).suffix
+                    if file_type not in self.parameters["file type"].enumeration:
+                        types = "', '".join(self.parameters["file type"].enumeration)
+                        raise RuntimeError(
+                            f"Cannot handle files of type '{file_type}' when reading "
+                            f"table '{tablename}'.\nKnown types: '{types}'"
+                        )
+                    lines.append(
+                        f"         File: '{filename}' with type '{file_type}' from the "
+                        "extension."
                     )
-                lines.append(
-                    f"         File: '{filename}' with type '{file_type}' from the "
-                    "extension."
-                )
             else:
                 lines.append(f"         File: '{filename}' with type '{file_type}'")
         elif method == "Save":
@@ -201,6 +207,9 @@ class Table(seamm.Node):
         )
         tablename = P["table name"]
 
+        # Pathnames are relative to current working directory
+        wd = Path(self.directory).parent
+
         # Print out header to the main output
         printer.important(self.description_text(P))
         printer.important("")
@@ -314,71 +323,81 @@ class Table(seamm.Node):
 
             self.logger.info("Successfully read table from {}".format(filename))
         elif P["method"] == "Save" or P["method"] == "Save as":
-            if not self.variable_exists(tablename):
-                raise RuntimeError(
-                    "Table save: table '{}' does not exist.".format(tablename)
-                )
-            file_type = P["file type"]
-            table_handle = self.get_variable(tablename)
-            table = table_handle["table"]
-            if P["method"] == "Save as":
-                filename = P["filename"]
-                table_handle["filename"] = filename
-            else:
-                if "filename" not in table_handle:
-                    if file_type == "from extension":
-                        file_type = ".csv"
-                    table_handle["filename"] = os.path.join(
-                        self.flowchart.root_directory, tablename + file_type
+            self.calls += 1
+            if self.calls % P["frequency"] == 0:
+                if not self.variable_exists(tablename):
+                    raise RuntimeError(
+                        "Table save: table '{}' does not exist.".format(tablename)
                     )
-                filename = table_handle["filename"]
+                file_type = P["file type"]
+                table_handle = self.get_variable(tablename)
+                table = table_handle["table"]
 
-            index = table_handle["index column"]
+                if P["method"] == "Save as":
+                    filename = P["filename"].strip()
+                    if filename.startswith("/"):
+                        filename = str(
+                            Path(self.flowchart.root_directory) / filename[1:]
+                        )
+                    else:
+                        filename = str(wd / filename)
+                    table_handle["filename"] = filename
+                else:
+                    if "filename" not in table_handle:
+                        if file_type == "from extension":
+                            file_type = ".csv"
+                        table_handle["filename"] = str(wd / tablename) + file_type
+                    filename = table_handle["filename"]
 
-            if file_type == "from extension":
-                file_type = PurePath(filename).suffix
-                if file_type not in self.parameters["file type"].enumeration:
+                index = table_handle["index column"]
+
+                if file_type == "from extension":
+                    file_type = PurePath(filename).suffix
+                    if file_type not in self.parameters["file type"].enumeration:
+                        types = "', '".join(self.parameters["file type"].enumeration)
+                        raise RuntimeError(
+                            f"Cannot handle files of type '{file_type}' when writing "
+                            f"table '{tablename}'.\nKnown types: '{types}'"
+                        )
+                if file_type == ".csv":
+                    if index is None:
+                        table.to_csv(filename, index=False)
+                    else:
+                        table.to_csv(filename, index=True, header=True)
+                elif file_type == ".json":
+                    if index is None:
+                        table.to_json(filename, indent=4, orient="table", index=False)
+                    else:
+                        table.to_json(filename, indent=4, orient="table", index=True)
+                elif file_type == ".xlsx":
+                    if index is None:
+                        table.to_excel(filename, index=False)
+                    else:
+                        table.to_excel(filename, index=True)
+                elif file_type == ".txt":
+                    with open(filename, "w") as fd:
+                        if index is None:
+                            fd.write(table.to_string(header=True, index=False))
+                        else:
+                            fd.write(table.to_string(header=True, index=True))
+                else:
                     types = "', '".join(self.parameters["file type"].enumeration)
                     raise RuntimeError(
-                        f"Cannot handle files of type '{file_type}' when writing "
-                        f"table '{tablename}'.\nKnown types: '{types}'"
+                        f"Table save: cannot handle format '{file_type}' for file "
+                        f"'{filename}'\nKnown types: '{types}'"
                     )
-            if file_type == ".csv":
-                if index is None:
-                    table.to_csv(filename, index=False)
-                else:
-                    table.to_csv(filename, index=True, header=True)
-            elif file_type == ".json":
-                if index is None:
-                    table.to_json(filename, indent=4, orient="table", index=False)
-                else:
-                    table.to_json(filename, indent=4, orient="table", index=True)
-            elif file_type == ".xlsx":
-                if index is None:
-                    table.to_excel(filename, index=False)
-                else:
-                    table.to_excel(filename, index=True)
-            elif file_type == ".txt":
-                with open(filename, "w") as fd:
-                    if index is None:
-                        fd.write(table.to_string(header=True, index=False))
-                    else:
-                        fd.write(table.to_string(header=True, index=True))
-            else:
-                types = "', '".join(self.parameters["file type"].enumeration)
-                raise RuntimeError(
-                    f"Table save: cannot handle format '{file_type}' for file "
-                    f"'{filename}'\nKnown types: '{types}'"
-                )
         elif P["method"] == "Print":
             table_handle = self.get_variable(tablename)
             table = table_handle["table"]
             index = table_handle["index column"]
-            printer.job("\nTable '{}':".format(tablename))
             if index is None:
-                printer.job(table.to_string(header=True, index=False))
+                text = table.to_string(header=True, index=False)
             else:
-                printer.job(table.to_string(header=True, index=True))
+                text = table.to_string(header=True, index=True)
+
+            for line in text.splitlines():
+                printer.normal(4 * " " + line)
+            printer.normal("")
 
         elif P["method"] == "Print the current row of":
             table_handle = self.get_variable(tablename)
@@ -396,10 +415,10 @@ class Table(seamm.Node):
             self.logger.debug("-----")
 
             if index == 0:
-                printer.job("\nTable '{}':".format(tablename))
-                printer.job("\n".join(lines.splitlines()[0:2]))
+                printer.normal("\n    Table '{}':".format(tablename))
+                printer.normal("\n    ".join(lines.splitlines()[0:2]))
             else:
-                printer.job(lines.splitlines()[index + 1])
+                printer.normal(4 * " " + lines.splitlines()[index + 1])
 
         elif P["method"] == "Append a row to":
             if not self.variable_exists(tablename):
