@@ -4,7 +4,7 @@
 """Tests for `table_step` running full flowcharts."""
 from pathlib import Path
 import pytest
-from seamm import run_flowchart
+from seamm_exec import run
 
 test_dir = Path(__file__).resolve().parent
 
@@ -25,4 +25,4 @@ def test_flowchart(monkeypatch, tmp_path, flowchart):
         ],
     )
 
-    run_flowchart(wdir=str(tmp_path))
+    run(wdir=str(tmp_path))
